plone.app.event.browser.formatted_date — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.browser.formatted_date

class `plone.app.event.browser.formatted_date.` `FormattedDateProvider`(context, request, view)

  Base class for objects that explicitly acquire attributes from containers

class `plone.app.event.browser.formatted_date.` `FormattedStartDateProvider`(context, request, view)

  Base class for objects that explicitly acquire attributes from containers

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »